summaryrefslogtreecommitdiff
path: root/src/mongo/db/query/count_command_as_aggregation_command.h
diff options
context:
space:
mode:
authorBernard Gorman <bernard.gorman@gmail.com>2021-03-24 14:07:04 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2021-04-02 21:51:14 +0000
commitea51edf33aa685e8b8d4692ee42b8c0e8e9cfb98 (patch)
treea3866340e9e80201eb9c9b675200700cc30ad53d /src/mongo/db/query/count_command_as_aggregation_command.h
parent0198bcfb938ccd788f90a2f5e6156871cf18330f (diff)
downloadmongo-ea51edf33aa685e8b8d4692ee42b8c0e8e9cfb98.tar.gz
SERVER-54975 Rename IDL parser classes to use CommandRequest and CommandReply suffixes
Diffstat (limited to 'src/mongo/db/query/count_command_as_aggregation_command.h')
-rw-r--r--src/mongo/db/query/count_command_as_aggregation_command.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/query/count_command_as_aggregation_command.h b/src/mongo/db/query/count_command_as_aggregation_command.h
index 05583f36e5a..05233278765 100644
--- a/src/mongo/db/query/count_command_as_aggregation_command.h
+++ b/src/mongo/db/query/count_command_as_aggregation_command.h
@@ -36,9 +36,9 @@
namespace mongo {
/**
* Converts this CountCommand into an aggregation.
*/
-StatusWith<BSONObj> countCommandAsAggregationCommand(const CountCommand& cmd,
+StatusWith<BSONObj> countCommandAsAggregationCommand(const CountCommandRequest& cmd,
const NamespaceString& nss);
} // namespace mongo
@@ -36,9 +36,9 @@
namespace mongo {
/**
- * Converts this CountCommand into an aggregation.
+ * Converts this CountCommandRequest into an aggregation.
*/